================================================================================
moban-handlebars
================================================================================

.. image:: https://api.travis-ci.org/moremoban/moban-handlebars.svg
   :target: http://travis-ci.org/moremoban/moban-handlebars

.. image:: https://codecov.io/github/moremoban/moban-handlebars/coverage.png
   :target: https://codecov.io/github/moremoban/moban-handlebars



With `pybars3 <https://github.com/wbond/pybars3>`_, this library allow moban users to
have handlebars template in their next documentation endeavour. 

Installation
================================================================================


You can install moban-handlebars via pip:

.. code-block:: bash

    $ pip install moban-handlebars


or clone it and install it:

.. code-block:: bash

    $ git clone https://github.com/moremoban/moban-handlebars.git
    $ cd moban-handlebars
    $ python setup.py install
